// BWCryptoDocument.h -- a document that stores the cryptogram string and 
//                       the letter mapping dictionary

#import <Cocoa/Cocoa.h>

@class BWCryptoView;

@interface BWCryptoDocument : NSDocument
{
    // the cryptogram string the user typed in
    NSString *originalString;

    // the mapping from the original crypto letters, to what the user
    // wants as a replacement
    NSMutableDictionary *letterMappingDict;

    // UI stuff we need references to
    IBOutlet BWCryptoView *cryptoView;
    IBOutlet NSMatrix *frequenciesMatrix;

    // connections for the cryptogram entry sheet
    IBOutlet NSWindow *stringEntrySheet;
    IBOutlet NSTextField *stringTextField;
}


// permute the letters.  Handy for creating new cryptograms.
- (IBAction) scrambleLetters: (id) sender;

// move the transmuted letters from the replacement letters into
// the original string.  Also handy for creating new cryptograms.
- (IBAction) copyReplacementLettersToCryptogram: (id) sender;

// drops the sheet so the user can enter the cryptogram
- (IBAction) enterCryptogram: (id) sender;

// replace the current cryptogram with a new one
- (IBAction) entrySheetOK: (id) sender;

// dismiss the sheet and pretend like nothing happened.
- (IBAction) entrySheetCancel: (id) sender;

@end

