// BWCryptoView.h -- interface to the view that will draw the string
//		     as a bunch of blocks, with the replacement letters
//		     seated on top of the original letter.


#import <Cocoa/Cocoa.h>

// an array of these is kept by the view, one for each character in
// the string

typedef struct LetterBlock {
    NSString *letter;			// the original letter
    NSRect  replacementLetterRect;	// where the replacement is drawn
    NSRect  letterRect;			// where the original letter is drawn
} LetterBlock;


// this notification is posted when the user changes a letter
extern NSString *BWCryptoView_LetterMapChangeNotification;

// in the notification userInfo dictionary, the original letter and
// replacement letter (as NSStrings) are stored under these keys
extern NSString *BWCryptoView_OriginalLetterKey;
extern NSString *BWCryptoView_NewLetterKey;


@interface BWCryptoView : NSView
{
    // the original cyphered string
    NSString *originalString;
    
    // keys are the original letters, values are the replacement letters
    NSDictionary *letterMappingDict;
    
    // number of letter blocks we have
    int blockCount;

    // malloc'd block of memory
    LetterBlock *blocks;

    // how to draw the characters.
    NSDictionary *letterAttributes;
    NSDictionary *replacementLetterAttributes;

    // this block is the selected one.  -1 for no blocks selected
    int selectedBlockIndex;

    // if the frame chagned
    BOOL needToLayOutBlocks;

}

// tell the view to draw another string.
- (void) setOriginalString: (NSString *) string;
- (NSString *) originalString;

// use this dictionary for mapping letters to their replacements
- (void) setLetterMappingDict: (NSDictionary *) dictionary;
- (NSDictionary *) letterMappingDict;

// something changed externaly, time to redraw
- (void) reloadData;

@end // BWCryptoView



